@@ -1,4 +1,4 @@
-from typing import Dict, Union, Type, Optional
+from typing import Dict, Union, Type, Optional, List
 
 from tagil.manager import InjectionManager
 
@@ -8,11 +8,12 @@ def component(
     *,
     name: str = None,
     inject: Optional[Dict[str, Union[str, Type]]] = None,
+    profile: Optional[Union[str, List[str]]] = None,
 ):
     if cls is None:
-        return lambda c: component(c, name=name, inject=inject)
+        return lambda c: component(c, name=name, inject=inject, profile=profile)
 
-    InjectionManager().register_component(cls, name, inject)
+    InjectionManager().register_component(cls, name, inject, profile=profile)
 
     return cls
 
@@ -22,8 +23,9 @@ def constructor(
     *,
     name: str = None,
     inject: Optional[Dict[str, Union[str, Type]]] = None,
+    profile: Optional[Union[str, List[str]]] = None,
 ):
     if method is None:
-        return lambda m: constructor(m, name=name, inject=inject)
+        return lambda m: constructor(m, name=name, inject=inject, profile=profile)
 
     InjectionManager().register_constructor(method, name, inject)
